@@ -26,18 +26,13 @@ use warnings;
 use List::MoreUtils qw(any);
 use Moo;
 
-use Lintian::Tags qw(tag);
-
 with('Lintian::Check');
 
 sub binary {
     my ($self) = @_;
 
     my $pkg = $self->package;
-    my $type = $self->type;
     my $info = $self->info;
-    my $proc = $self->processable;
-    my $group = $self->group;
 
     return if # Big exception list for all tags
       $pkg =~ /^perl(?:-base)?$/                    or # perl itself
@@ -82,16 +77,16 @@ sub binary {
     # Check for library style package names
     if ($pkg =~ /^lib(?:.+)-perl$|^ruby-|^python[\d.]*-/) {
         if ($pkg =~ /^libapp(?:.+)-perl$/) {
-            tag 'libapp-perl-package-name', @programs;
+            $self->tag('libapp-perl-package-name', @programs);
         } else {
-            tag 'library-package-name-for-application', @programs;
+            $self->tag('library-package-name-for-application', @programs);
         }
     }
 
     # Check for wrong section
     my $section = $info->field('section', '');
     if ($section =~ /perl|python|ruby|(?:^|\/)libs/) { # oldlibs is ok
-        tag 'application-in-library-section', "$section", @programs;
+        $self->tag('application-in-library-section', "$section", @programs);
     }
 
     return;
